package cn.com.ty.lift.business.project.controller;

import cn.com.ty.lift.business.framework.util.MessageUtils;
import cn.com.ty.lift.business.project.dao.entity.model.request.CompanyRequest;
import cn.com.ty.lift.business.project.dao.entity.model.request.ProjectDetailRequest;
import cn.com.ty.lift.business.project.dao.entity.model.response.ProjectCompanyResponse;
import cn.com.ty.lift.business.project.dao.entity.model.response.ProjectLiftResponse;
import cn.com.ty.lift.business.project.service.ProjectAppService;
import cn.com.ty.lift.common.constants.ApiConstants;
import cn.com.xwy.boot.web.dto.RestResponse;
import cn.hutool.core.util.ObjectUtil;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import javax.validation.Valid;

/**
 * @author bieao
 * @date 2019/12/31
 * @description app端项目管理控制层
 */
@RestController
@RequestMapping("app")
public class ProjectAppController {

    @Resource
    private ProjectAppService projectAppService;

    /**
     * @param request 公司id
     * @return RestResponse 项目列表
     * @description 根据公司id查询公司下项目列表
     * @date 2019/12/31 3:13 PM
     */
    @PostMapping("project/list")
    public RestResponse list(@Valid @RequestBody CompanyRequest request) {
        IPage<ProjectCompanyResponse> page = projectAppService.list(request);
        if (ObjectUtil.isEmpty(page.getRecords())) {
            return RestResponse.success();
        }
        return RestResponse.success(page, ApiConstants.RESULT_SUCCESS, MessageUtils.get("msg.query.success"));
    }

    /**
     * @param request 项目id
     * @return RestResponse 电梯列表
     * @description 根据项目id查询项目下电梯列表
     * @date 2019/12/31 3:13 PM
     */
    @PostMapping("lift/list")
    public RestResponse list(@Valid @RequestBody ProjectDetailRequest request) {
        IPage<ProjectLiftResponse> page = projectAppService.list(request);
        if (ObjectUtil.isEmpty(page.getRecords())) {
            return RestResponse.success();
        }
        return RestResponse.success(page, ApiConstants.RESULT_SUCCESS, MessageUtils.get("msg.query.success"));
    }
}
