package cn.com.ty.lift.enterprise.oa.controller;

import cn.com.ty.lift.common.utils.AliyunOSSUtil;
import cn.com.ty.lift.enterprise.common.Conf;
import cn.com.ty.lift.enterprise.common.CountPage;
import cn.com.ty.lift.enterprise.oa.dto.LiftCertificateRequest;
import cn.com.ty.lift.enterprise.oa.dto.LiftCertificateResponse;
import cn.com.ty.lift.enterprise.oa.entity.LiftCertificate;
import cn.com.ty.lift.enterprise.oa.service.LiftCertificateService;
import cn.com.xwy.boot.web.dto.RestResponse;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.IdWorker;
import lombok.AllArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.multipart.MultipartFile;


/**
 * <p>
 * 操作证 前端控制器
 * </p>
 *
 * @author wcz
 * @since 2019-12-04
 */
@Slf4j
@AllArgsConstructor
@RestController
@RequestMapping("/oa/liftCertificate")
public class LiftCertificateController {
    private LiftCertificateService liftCertificateService;

    private AliyunOSSUtil aliyunOSSUtil;

    private Conf conf;

    /**
     * @description 根据id查找
     * @date 2019/12/6 9:45
     * @param
     * @return
     */
    @PostMapping("findOne")
    public RestResponse findOne(@RequestBody LiftCertificateRequest request) {
        long id = request.getId();
        if(id <= 0){
            return RestResponse.failParam();
        }
        LiftCertificate entity = liftCertificateService.getById(id);
        if(null == entity){
            return RestResponse.fail();
        }
        return RestResponse.success(entity);
    }

    /**
     * @description 根据条件查询
     * @date 2019/12/6 9:45
     * @param
     * @return
     */
    @PostMapping("list")
    public RestResponse list(@RequestBody LiftCertificateRequest request) {

        String name = request.getUsername();
        //name 模糊查询
        if (StrUtil.isNotBlank(name)) {
            request.setUsername(StrUtil.format("%{}%",name));
        }
        IPage<LiftCertificateResponse> pages = liftCertificateService.selectByCondition(request);
        if (pages == null) {
            return RestResponse.fail();
        }
        long count = liftCertificateService.countByCondition(request);
        CountPage<LiftCertificateResponse> countPage = new CountPage<>(count, pages);
        return RestResponse.success(countPage);
    }

    /**
     * @description 更新操作证信息
     * @date 2019/12/4 10:32
     * @param
     * @return
     */
    @PostMapping("modify")
    public RestResponse modify(@RequestBody LiftCertificate entity) {
        if (null == entity) {
            return RestResponse.failParam();
        }
        boolean result = liftCertificateService.updateById(entity);
        if (result) {
            return RestResponse.success(result);
        }
        return RestResponse.fail();
    }

    /**
     * @description 操作证审核
     * @date 2019/12/4 10:32
     * @param
     * @return
     */
    @PostMapping("audit")
    public RestResponse audit(@RequestBody LiftCertificateRequest request) {
        long id = request.getId();
        if(id <= 0){
            return RestResponse.failParam();
        }
        //0：无证，1：待审核，2：审核未通过，3：审核通过，4：超期
        LiftCertificate liftCertificate = liftCertificateService.getById(id);
        if(null == liftCertificate){
            return RestResponse.failParam();
        }
        int status = request.isPass() ? 3 : 2;
        liftCertificate.setStatus(status);
        boolean result = liftCertificateService.saveOrUpdate(liftCertificate);
        if(result){
            return RestResponse.success(result);
        }
        return RestResponse.fail();
    }

    /**
     * @description 新增操作证
     * @date 2019/12/4 10:31
     * @param
     * @return
     */
    @PostMapping("add")
    public RestResponse add(MultipartFile[] files,LiftCertificate entity) throws Exception{
        if(null == files || files.length == 0){
            return RestResponse.fail("请上传操作证图片");
        }

        if (null == entity) {
            return RestResponse.failParam();
        }
        for (int i = 0;i < files.length; i++){
            MultipartFile file = files[i];
            if(file.isEmpty()){
                return RestResponse.fail("请上传操作证图片");
            }
            String originalFilename = file.getOriginalFilename();
            String suffix = originalFilename.substring(originalFilename.indexOf("."));
            String fileName = IdWorker.getId() + suffix;
            log.info("fileName: {}" ,fileName);
            byte[] bytes = file.getBytes();
            boolean ret = aliyunOSSUtil.putObject(conf.bucketName,bytes,fileName);
            if(ret){
                if(i == 0){
                    entity.setFirstImgUrl(fileName);
                }else{
                    entity.setSecondImgUrl(fileName);
                }
            }

        }
        boolean result = liftCertificateService.save(entity);
        if(result){
            return RestResponse.success(result);
        }
        return RestResponse.fail();

    }
}
